@@ -3,14 +3,15 @@ import os
 import sys
 
 __package__ = "meld"
-__version__ = "3.18.1"
+__version__ = "3.18.2"
 
 # START; these paths are clobbered on install by meld.build_helpers
 DATADIR = os.path.join(sys.prefix, "share", "meld")
 LOCALEDIR = os.path.join(sys.prefix, "share", "locale")
 # END
-UNINSTALLED = False
-UNINSTALLED_SCHEMA = False
+
+# Flag enabling some workarounds if data dir isn't installed in standard prefix
+DATADIR_IS_UNINSTALLED = False
 PYTHON_REQUIREMENT_TUPLE = (3, 3)
 
 # Installed from main script
@@ -19,13 +20,13 @@ ngettext = lambda x, *args: x
 
 
 def frozen():
-    global DATADIR, LOCALEDIR, UNINSTALLED_SCHEMA
+    global DATADIR, LOCALEDIR, DATADIR_IS_UNINSTALLED
 
     melddir = os.path.dirname(sys.executable)
 
     DATADIR = os.path.join(melddir, "share", "meld")
     LOCALEDIR = os.path.join(melddir, "share", "mo")
-    UNINSTALLED_SCHEMA = True
+    DATADIR_IS_UNINSTALLED = True
 
     # This first bit should be unnecessary, but some things (GTK icon theme
     # location, GSettings schema location) don't fall back correctly.
@@ -35,14 +36,13 @@ def frozen():
 
 
 def uninstalled():
-    global DATADIR, LOCALEDIR, UNINSTALLED, UNINSTALLED_SCHEMA
+    global DATADIR, LOCALEDIR, DATADIR_IS_UNINSTALLED
     melddir = os.path.abspath(os.path.join(
         os.path.dirname(os.path.realpath(__file__)), ".."))
 
     DATADIR = os.path.join(melddir, "data")
     LOCALEDIR = os.path.join(melddir, "build", "mo")
-    UNINSTALLED = True
-    UNINSTALLED_SCHEMA = True
+    DATADIR_IS_UNINSTALLED = True
 
     # This first bit should be unnecessary, but some things (GTK icon theme
     # location, GSettings schema location) don't fall back correctly.
